#!/usr/bin/python3
# -*- coding:utf-8 -*-
"""
Programme classique lecture entrée GPIO avec la bibliothèque RPi.GPIO
utilisation anti-rebond logiciel
Bouton poussoir raccordé entre GPIO22 et +3.3V 
(avec résistance de protection de 1k en série)
nom programme       : push05.py
logiciel            : python 3.4.2
cible               : raspberry Pi
date de création    : 18/08/2016
date de mise à jour : 18/08/2016
version             : 1.0
auteur              : icarePetibles
référence           : 
"""
#-------------------------------------------------------------------------------
# Bibliothèques
#-------------------------------------------------------------------------------
import RPi.GPIO as GPIO                 #bibliothèque RPi.GPIO
import time                             #bibliothèque time
from threading import *                 #bibliothèque thread
#-------------------------------------------------------------------------------
pin = 22                                #broche utilisé en entrée
debounce = 100                          #attente anti-rebond
etatBouton = False                      #bouton au repos

GPIO.setwarnings(False)                 #désactive le mode warning
GPIO.setmode(GPIO.BCM)                  #utilisation des numéros de ports du
                                        #processeur
GPIO.setup(pin, GPIO.IN, pull_up_down=GPIO.PUD_DOWN)
                                        #mise en entrée du port GPIO 22
                                        #et activation résistance soutirage
                                        #au ground
enMarche = True                         #sortie boucle

class Saisie(Thread):
    """Lanceur de fonction"""
    def __init__(self, fonction):
        Thread.__init__(self, None, fonction)
        self._fonction = fonction
        self.running = True
        
    def run(self):                      #lance le programme
        while self.running:
            self._fonction()            #notre fonction programme
    
    def stop(self):                     #arrêt du programme
        self.running = False
        
def saisieClavier():
    """Saisie <Entrée>"""
    global enMarche
    while enMarche:                     #tant que en marche
        input()                         #attente saisie clavier
        sortie = True                   #on sort
        enMarche = False                #sortie boucle
    
if __name__ == '__main__':
    """
    Programme par défaut
    """
    print("Début du programme")         #IHM
    print("Sortie par <Entrée>\n")      #IHM
    thread_1 = Saisie(saisieClavier)    #création thread
    thread_1.start()                    #démarre le thread
    while enMarche:                     #boucle infinie contrôlée
        lecture1 = GPIO.input(pin)      #première lecture entrée
        etat1 = lecture1                #mémorise la lecture
        if(etat1 != etatBouton):        #si première lecture différente
                                        #etatBouton
            time.sleep(debounce / 1000) #attente fin rebondissement contact
        lecture2 = GPIO.input(pin)      #deuxième lesture entrée
        etat2 = lecture2                #mémorise la lecture
        if(etat1 == etat2):             #si etat1 = etat2
            etatBouton = etat2          #alors changement état BP
                
        if(etatBouton == True):         #si BP appuyé
            print("BP appyué")          #alors affiche message
            etatBouton = False          #BP relaché

    thread_1.stop()                     #arrêt thread
    GPIO.cleanup()                      #libère toutes les ressources
    print("Fin du programme")           #IHM
