#!/usr/bin/python3
# -*- coding:utf-8 -*-
"""
Programme classique lecture entrée GPIO avec la bibliothèque gpiozero
utilisation anti-rebond logiciel
Bouton poussoir raccordé entre GPIO22 et +3.3V 
(avec résistance de protection de 1k en série)
nom programme       : push25.py
logiciel            : python 3.4.2
cible               : raspberry Pi
date de création    : 18/08/2016
date de mise à jour : 18/08/2016
version             : 1.0
auteur              : icarePetibles
référence           : 
"""
#-------------------------------------------------------------------------------
# Bibliothèques
#-------------------------------------------------------------------------------
from gpiozero import Button             #bibliothèque gpiozero
import time                             #bibliothèque time
from threading import *                 #bibliothèque thread
#-------------------------------------------------------------------------------
pin = 22                                #broche utilisé en entrée
debounce = 0.1                          #attente anti-rebond

bouton = Button(pin, pull_up=False, bounce_time=debounce)
                                        #instance bouton sur GPIO22 avec
                                        #résistance de soutirage vers la masse
                                        #et temps de rebondissement de 100 ms
enMarche = True                         #sortie boucle

class Saisie(Thread):
    """Lanceur de fonction"""
    def __init__(self, fonction):
        Thread.__init__(self, None, fonction)
        self._fonction = fonction
        self.running = True
        
    def run(self):                      #lance le programme
        while self.running:
            self._fonction()            #notre fonction programme
    
    def stop(self):                     #arrêt du programme
        self.running = False
        
def saisieClavier():
    """Saisie <Entrée>"""
    global enMarche
    while enMarche:                     #tant que en marche
        input()                         #attente saisie clavier
        sortie = True                   #on sort
        enMarche = False                #sortie boucle
    
if __name__ == '__main__':
    """
    Programme par défaut
    """
    print("Début du programme")         #IHM
    print("Sortie par <Entrée>\n")      #IHM
    thread_1 = Saisie(saisieClavier)    #création thread
    thread_1.start()                    #démarre le thread
    while enMarche:                     #boucle infinie contrôlée
        if bouton.is_pressed:           #si BP appuyé
            print("BP appyué")          #alors affiche message
        time.sleep(0.15)                #ralentit le programme

    thread_1.stop()                     #arrêt thread
    bouton.close()                      #libère la ressource
    print("Fin du programme")           #IHM
