/* -----------------------------------------------------------------------------
Programme classique lecture entrée GPIO avec la bibliothèque wiringPi
Bouton poussoir raccordé entre GPIO22 et +3.3V
(avec une résistance de protection de 1k en série)
nom programme       : push10.c
os                  : RPi Linux 4.4.13+
logiciel            : gcc (Raspbian 4.9.2-10) 4.9.2
cible               : raspberry Pi
date de création    : 24/08/2016
date de mise à jour : 24/08/2016
version             : 1.0
auteur              : icarePetibles
référence           : www.wiringpi.com
Remarques           :

Bibliothèques
----------------------------------------------------------------------------- */
#include <stdio.h>                      //entrées/sorties
#include <wiringPi.h>                   //bibliothèque wiringPi
#include <stdlib.h>                     //conversion nombre
#include <string.h>                     //chaîne
#include <pthread.h>                    //thread

#define TEST                            //voir commentaire

#define PIN 3                           //numéro bouton = GPIO22
#define DEBOUNCE 100                    //temps rebondissement

typedef enum                            //pour palier non existance type booléen
    {False=0, True=1}
    Bool;

volatile Bool enMarche = True;          //variable globale contrôle boucle

#ifdef TEST
void* saisieClavier(){                  //attente saisie clavier (thread)
    while(enMarche){                    //en fonctionnement
        getchar();                      //attente saisie clavier
        enMarche = False;               //arrêt
    }
    return 0;                           //valeur retour
}
#endif

int main(void){                         //programme principal
    Bool etatBouton = False;            //variable état du bouton
    Bool lecture1 = False, lecture2 = False;
    Bool etat1 = False, etat2 = False;
    wiringPiSetup();                    //numérotation wiringPi ou type Arduino
    pinMode(PIN, INPUT);                //pin en entrée
    pullUpDnControl(PIN, PUD_DOWN);     //résistance soutirage à la masse
#ifdef TEST
    pthread_t saisie;                   //instance thread
    printf("Début programme\n");        //IHM
    printf("sortie par touche <Entrée>\n\n");
                                        //IHM
    pthread_create(&saisie, NULL, saisieClavier, NULL);
                                        //création thread
#endif
    while(enMarche){                    //tant que l'on fonctionne
        lecture1 = digitalRead(PIN);    //lecture état BP
        etat1 = lecture1;               //sauve le résultat
        if(etat1 != etatBouton)         //si différent de l'état actuel
            delay(DEBOUNCE);            //attente fin rebondissement
        lecture2 = digitalRead(PIN);    //re-lecture état BP
        etat2 = lecture2;               //sauve le résultat
        if(etat1 == etat2)              //compare les 2 lectures sont identiques
            etatBouton = etat2;         //nouvel état

        if(etatBouton == True){         //si BP appuyé
            printf("BP appuyé\n");      //IHM
            etatBouton = False;         //remise à 0
        }
    }
#ifdef TEST
    printf("Fin du programme\n");       //IHM
#endif
    return(0);                          //code sortie
}
//------------------------------------------------------------------------------
