/* -----------------------------------------------------------------------------
Programme classique lecture entrée GPIO avec la bibliothèque wiringPi
Bouton poussoir raccordé entre GPIO22 et +3.3V
(avec une résistance de protection de 1k en série)
nom programme       : push20.cpp
os                  : RPi Linux 4.4.13+
logiciel            : g++ (Raspbian 4.9.2-10) 4.9.2
cible               : raspberry Pi
date de création    : 24/08/2016
date de mise à jour : 24/08/2016
version             : 1.0
auteur              : icarePetibles
référence           : www.wiringpi.com
Remarques           :

Bibliothèques
----------------------------------------------------------------------------- */
#include <cstdio>                       //entrées/sorties
#include <wiringPi.h>                   //bibliothèque wiringPi
#include <iostream>                     //entrées/sorties standard
#include <sstream>                      //buffer
#include <stdlib.h>                     //conversion nombre
#include <pthread.h>                    //thread

bool lectureBP(int pin, bool etatBouton);
                                        //prototype fonction lecture BP

using namespace std;

#define TEST                            //voir commentaire

#define PIN 3                           //numéro bouton = GPIO22
#define DEBOUNCE 100                    //temps rebondissement

volatile bool enMarche(true);           //variable globale contrôle boucle

#ifdef TEST
void* saisieClavier(void *){            //attente saisie clavier (thread)
    while(enMarche){                    //en fonctionnement
        cin.ignore();                   //attente saisie clavier
        enMarche = false;               //arrêt
    }
    return 0;                           //valeur retour
}
#endif

int main(void){                         //programme principal
    bool etatBouton(false);             //variable état du bouton
    wiringPiSetup();                    //numérotation wiringPi ou type Arduino
    pinMode(PIN, INPUT);                //pin en entrée
    pullUpDnControl(PIN, PUD_DOWN);     //résistance soutirage à la masse
#ifdef TEST
    pthread_t saisie;                   //instance thread
    cout << "Début programme" << endl;  //IHM
    cout << "sortie par la touche <Entrée>" << endl << endl;
                                        //IHM
    pthread_create(&saisie, NULL, saisieClavier, NULL);
                                        //création thread
#endif
    while(enMarche){                    //tant que l'on fonctionne
        if(lectureBP(PIN, etatBouton)){ //lecture BP
            cout << "BP appuyé" << endl;//IHM
            etatBouton = false;         //remise à 0
        }
    }
#ifdef TEST
    cout << "Fin du programme" << endl;
#endif
    return(0);                          //code sortie
}
//------------------------------------------------------------------------------
bool lectureBP(int pin, bool etatBouton){
    bool lecture1(false), lecture2(false);
    bool etat1(false), etat2(false);    //variables booléen et initialisation
    lecture1 = digitalRead(pin);        //lecture état BP
    etat1 = lecture1;                   //sauve le résultat
    if(etat1 != etatBouton)             //si différent de l'état actuel
        delay(DEBOUNCE);                //attente fin rebondissement
    lecture2 = digitalRead(pin);        //re-lecture état BP
    etat2 = lecture2;                   //sauve le résultat
    if(etat1 == etat2)                  //compare les deux lectures
        etatBouton = etat2;             //nouvel état
    return etatBouton;                  //retourne état du bouton
}
//------------------------------------------------------------------------------
