#!/bin/bash
#Programme classique lecture entrée GPIO via driver linux
#Anti-rebond logiciel
#Bouton poussoir raccordé entre GPIO22 et +3.3V
#(avec résistance de protection de 1k en série)
#nom programme       : push30.sh
#logiciel            : bash
#cible               : raspberry Pi
#date de création    : 18/06/2016
#date de mise à jour : 18/07/2016
#version             : 1.0
#auteur              : icarePetibles
#référence           :
#Remarques           : Pour fonctionner, il faut être sous super utilisateur
#                      Il faut rendre le fichier exécutable avec
#                      sudo chmod +x push30.sh
#                      Pour exécuter le fichier, il faut faire
#                      sudo ./push30.sh
#
BPPIN=22                                            #GPIO22
FALSE=0
TRUE=1
DEBOUNCE=0.05                                       #temps rebondissement
etatBouton=0                                        #BP relaché

#vérification si accès root
#if [ $EUID -ne 0 ]                                  #si $EUID différent de 0
if [ $EUID != "0" ]                                 #si $EUID différent de 0
then                                                #alors
    echo "Il faut être root pour exécuter le script. Essaye sudo $0"
    exit                                            #sortie
fi                                                  #fin if

#Procédure de netoyage, désactive l'entrée
cleanup()
{
    PIN=$1                                          #paramètre transmis
    echo $PIN > /sys/class/gpio/unexport            #désactive port
    echo                                            #esthétique
    echo Fin script                                 #message de fin
    exit                                            #sortie
}

#programme principal
echo Début du script                                #IHM
echo ctrl-c pour sortir de la boucle                #IHM
echo
#Setup pin et direction - Cature Control-C SIGHUP SIGKILL
echo $BPPIN > /sys/class/gpio/export                #assigne pin 23
echo in > /sys/class/gpio/gpio$BPPIN/direction      #pin 22 en entrée
trap "cleanup $BPPIN" SIGHUP SIGINT SIGTERM         #capture SIGNAL et lance la
                                                    #la procédure cleanup avec
                                                    #le paramètre 22
while true                                          #boucle infinie
  do                                                #faire
    lecture1=`cat /sys/class/gpio/gpio$BPPIN/value` #lecture entrée BP
    etat1=$lecture1                                 #mémorise la lecture
    if [ $etat1 -ne $etatBouton ]                   #si lecture <> état BP
    then
        sleep $DEBOUNCE                             #attente fin rebondissement
    fi
    lecture2=`cat /sys/class/gpio/gpio$BPPIN/value` #re-lecture entrée BP
    etat2=$lecture2                                 #mémorise la lecture
    if [ $etat1 -eq $etat2 ]                        #si etat1 = etat2
    then
        etatBouton=$etat2                           #alors changement état BP
    fi

    if [ $etatBouton -eq $TRUE ]                    #si BP appuyé
    then
        echo BP appuyé                              #affiche message
        etatBouton=$FALSE                           #BP relâché
    fi
  done                                              #fin do
#Fin du script

